@@ -14,10 +14,10 @@ Label(text="Welcome to my app it needs Xterm terminal software\nand sudo permiss
 
 
 def deger1():
-    os.system("xterm -hold -e sudo cp Kyak2-Void.py /usr/share/applications")
-    os.system("xterm -hold -e sudo cp Kyak2-Void.desktop /usr/share/applications")
+    os.system("xterm -hold -e sudo cp Kyak2-Void.py /usr/share/applications/")
+    os.system("xterm -hold -e sudo cp Kyak2-Void.desktop /usr/share/applications/")
 def deger2():
-    os.system("xterm -hold -e sudo cp Kyak2-Void.py /usr/bin")
+    os.system("xterm -hold -e sudo cp Kyak2-Void.py /usr/bin/")
 def deger3():
     os.system("xterm -hold -e sudo rm /usr/share/applications/Kyak2-Void.py")
     os.system("xterm -hold -e sudo rm /usr/share/applications/Kyak2-Void.desktop")
